<?php
/**
 * Webkul MarketingCloud Magento Connector SyncOrder Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Order;

use Magento\Backend\App\Action\Context;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;
use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;

class SyncOrder extends \Magento\Sales\Controller\Adminhtml\Order\AbstractMassAction
{
    /**
     * @param Action\Context $context
     * @param Filter $filter
     * @param CollectionFactory $collectionFactory
     */
    public function __construct(
        Filter $filter,
        Context $context,
        CollectionFactory $collectionFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection
    ) {
        $this->collectionFactory = $collectionFactory;
        $this->_connection = $connection;
        $this->_storeManager = $storeManager;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        parent::__construct($context, $filter);
    }

    protected function massAction(AbstractCollection $collection)
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if(isset($token) && $token != null){
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        //$storeId = (int) $this->getRequest()->getParam('store', 0);
        $storeId = $this->_storeManager->getStore()->getId();
        $storeName = $this->_storeManager->getStore()->getName();
       
        $helper = $this->_connection;

        $res = $helper->getSyncOrder($collection);

        if($res && $res[0]){
            $message = "Order Successfully Exported In DataExtension!!!";
            $this->_messageManager->addSuccess(__($message));
        } else{
            $this->_messageManager->addSuccess(__("All Magento Order are exported Successfully!!"));
        }

        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath($this->getComponentRefererUrl());
        return $resultRedirect;
    }
}
