<?php
/**
 * Webkul MarketingCloudMagentoConnector CustomerSaveAfterObserver Observer Model
 *
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 *
 */
namespace Webkul\MarketingCloudMagentoConnector\Observer;

use Magento\Framework\Event\Manager;
use Magento\Framework\Event\ObserverInterface;
use Webkul\MarketingCloudMagentoConnector\Helper\Connection;

class NewsLetterSaveObserver implements ObserverInterface
{
    protected $_state;

    public function __construct(
        \Magento\Framework\App\RequestInterface $requestInterface,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Framework\App\State $state
    ) {
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_requestInterface = $requestInterface;
        $this->_state = $state;
    }

    /**
     * NewsLetter save after event handler
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $areaCode = $this->_state->getAreaCode();
        $subscriberId = $observer->getEvent()->getSubscriber()->getId();
        $subscriberEmail = $observer->getEvent()->getSubscriber()->getEmail();
        
        $helper = $this->_connection;
        $autoSync = $this->_scopeConfig->getValue('marketingcloud/general/mc_autosync');
        $subscriberIdArray = array(
            '0'=>$subscriberId
        );
        if ($subscriberId && $autoSync == '1') {
            $res = $helper->SyncSubscriberToList($subscriberIdArray);
            if($res && $res[0]){
                $message = "Subscriber(s) added to the  selected list Successfully!!";
                if ($areaCode!='frontend') {
                    $this->_messageManager->addSuccess(__($message));
                }
            } else{
                if ($areaCode!='frontend') {
                    $this->_messageManager->addError(__("Please select the list in marketing cloud configuration."));
                }
            }
        }
    }
}
